@@ -51,6 +51,7 @@ class ALCConfig:
         self.which = 'both'
         self.since = None
         self.reverse = False
+        self.no_network = False
         self.select_frontend = False
         self.ignore_apt_assume = False
         self.ignore_debian_frontend = False
@@ -59,7 +60,7 @@ class ALCConfig:
         # - options that can be also used for command line parameters
         #   (after replacing '_' with '-', and adding trailing '=' if needed)
         self._bool_opts = ['confirm', 'debug', 'show_all', 'headers', 'verbose', 'reverse',
-                           'dump_seen', 'select_frontend',
+                           'dump_seen', 'select_frontend', 'no_network',
                            'ignore_apt_assume', 'ignore_debian_frontend']
         self._value_opts = ['frontend', 'email_address', 'email_format', 'save_seen', 'since', 'which']
         # - options that can be given only in the config file
@@ -165,6 +166,8 @@ class ALCConfig:
             # Prefer APT_LISTCHANGES_FRONTEND over DEBIAN_FRONTEND
             self.ignore_debian_frontend = True
 
+        (since, show_all) = (None, False)
+
         # Command-line options override environment and config file
         for opt, arg in optlist:
             if opt == '--help':
@@ -180,9 +183,9 @@ class ALCConfig:
             elif opt in ('-c', '--confirm'):
                 self.confirm = True
             elif opt in ('--since'):
-                self.since = arg
+                since = arg
             elif opt in ('-a', '--show-all', '--all'):
-                self.show_all = True
+                show_all = True
             elif opt in ('-h', '--headers'):
                 self.headers = True
             elif opt in ('--save-seen', '--save_seen'):
@@ -195,6 +198,8 @@ class ALCConfig:
                 self.debug = True
             elif opt == '--reverse':
                 self.reverse = True
+            elif opt in ('-n', '--no-network'):
+                self.no_network = True
             elif opt == '--select-frontend':
                 self.select_frontend = True
             elif opt == '--ignore-apt-assume':
@@ -207,9 +212,17 @@ class ALCConfig:
         if self.save_seen == 'none':
             self.save_seen = None
 
+        if ((self.since is not None and self.show_all)
+           or (since is not None and show_all)):
+                ALCLog.error(_('--since=<version> and --show-all are mutually exclusive'))
+                sys.exit(1)
+        elif since is not None or show_all:
+            self.since = since
+            self.show_all = show_all
+
         if self.since is not None:
-            if len(args) is not 1:
-                self.stderr.write(_('--since=<version> expects a only path to a .deb') + "\n")
+            if len(args) != 1:
+                ALCLog.error(_('--since=<version> expects a path to exactly one .deb archive'))
                 sys.exit(1)
             self.save_seen = None
 
